@@ -1,4 +1,5 @@
 import base64
+from typing import List, Type
 
 import pytest
 
@@ -8,17 +9,16 @@ pytest.importorskip('google.protobuf')
 
 from google.protobuf import json_format  # noqa
 from google.protobuf.struct_pb2 import Value  # noqa
+from google.protobuf.message import Message as ProtoMessage  # noqa
 
 from hedwig.testing.factories.protobuf import ProtobufMessageFactory  # noqa
 from hedwig.validators.protobuf import ProtobufValidator, SchemaError  # noqa
-from hedwig.container_pb2 import PayloadV1  # noqa
+from hedwig.protobuf.container_pb2 import PayloadV1  # noqa
 from tests.models import MessageType  # noqa
 from tests.schemas.protos import (  # noqa
     protobuf_pb2,
     protobuf_minor_versioned_pb2,
-    protobuf_bad1_pb2,
-    protobuf_bad2_pb2,
-    protobuf_bad3_pb2,
+    protobuf_bad_pb2,
 )
 from tests import test_validators  # noqa
 
@@ -27,25 +27,64 @@ class TestProtobufValidator:
     def _validator(self):
         return ProtobufValidator()
 
-    def test_constructor_checks_schema(self):
-        with pytest.raises(SchemaError):
-            ProtobufValidator(test_validators)
-
     @pytest.mark.parametrize(
-        'schema_module,schema_exc_error',
+        'proto_messages,schema_exc_error',
         [
-            [protobuf_bad1_pb2, "Protobuf message class not found for 'trip_created' v1"],
-            [protobuf_bad2_pb2, "Protobuf message class not found for 'trip_created' v2"],
             [
-                protobuf_bad3_pb2,
-                "Protobuf message class 'TripCreatedV1' option message_options.major_version isn't valid: 2, "
-                "expected: 1",
+                [
+                    protobuf_bad_pb2.DeviceCreated,
+                    protobuf_pb2.TripCreatedV1,
+                    protobuf_pb2.TripCreatedV2,
+                    protobuf_pb2.DeviceCreatedV1,
+                    protobuf_pb2.VehicleCreatedV1,
+                ],
+                "Couldn't determine message type for Protobuf message class '<class 'protobuf_bad_pb2.DeviceCreated'>'",
+            ],
+            [
+                [
+                    protobuf_pb2.TripCreatedV1,
+                    protobuf_pb2.DeviceCreatedV1,
+                    protobuf_pb2.VehicleCreatedV1,
+                ],
+                "Invalid message_type, major version: 'trip_created/2', not found in declared messages",
+            ],
+            [
+                [
+                    protobuf_bad_pb2.TripCreatedV3,
+                    protobuf_pb2.TripCreatedV1,
+                    protobuf_pb2.TripCreatedV2,
+                    protobuf_pb2.DeviceCreatedV1,
+                    protobuf_pb2.VehicleCreatedV1,
+                ],
+                "Protobuf message class '<class 'protobuf_bad_pb2.TripCreatedV3'>' mismatch in major version: '3' !="
+                " '2'",
+            ],
+            [
+                [
+                    protobuf_bad_pb2.TripCreated,
+                    protobuf_pb2.TripCreatedV1,
+                    protobuf_pb2.TripCreatedV2,
+                    protobuf_pb2.DeviceCreatedV1,
+                    protobuf_pb2.VehicleCreatedV1,
+                ],
+                "Duplicate Protobuf message declared for 'trip_created/1'",
+            ],
+            [
+                [
+                    protobuf_bad_pb2.TripCreatedV4,
+                    protobuf_pb2.TripCreatedV1,
+                    protobuf_pb2.TripCreatedV2,
+                    protobuf_pb2.DeviceCreatedV1,
+                    protobuf_pb2.VehicleCreatedV1,
+                ],
+                "Protobuf message class '<class 'protobuf_bad_pb2.TripCreatedV4'>' does not define option "
+                "message_options",
             ],
         ],
     )
-    def test_check_schema(self, schema_module: str, schema_exc_error):
+    def test_check_schema(self, proto_messages: List[Type[ProtoMessage]], schema_exc_error):
         with pytest.raises(SchemaError) as exc_context:
-            ProtobufValidator(schema_module)
+            ProtobufValidator(proto_messages)
 
         assert schema_exc_error in exc_context.value.args[0]
 
@@ -159,7 +198,7 @@ class TestProtobufValidator:
             message_payload = message.data.SerializeToString()
             attributes = {
                 "hedwig_format_version": '1.0',
-                "hedwig_schema": "https://hedwig.automatic.com/schema#/schemas/trip_created/1.0",
+                "hedwig_schema": "https://github.com/cloudchacho/hedwig-python/schema#/schemas/trip_created/1.0",
                 "hedwig_id": message.id,
                 "hedwig_publisher": message.publisher,
                 "hedwig_message_timestamp": str(message.timestamp),
@@ -246,9 +285,7 @@ class TestProtobufValidator:
         }
         with pytest.raises(ValidationError) as e:
             validator.deserialize(payload, attrs, None)
-        assert (
-            e.value.args[0] == "Protobuf message class not found for 'trip_created' v9. Must be named 'TripCreatedV9'"
-        )
+        assert e.value.args[0] == "Protobuf message class not found for 'trip_created/9'"
 
     def test_deserialize_raises_error_invalid_schema_container(self, settings):
         settings.HEDWIG_USE_TRANSPORT_MESSAGE_ATTRIBUTES = False
@@ -277,9 +314,7 @@ class TestProtobufValidator:
 
         with pytest.raises(ValidationError) as e:
             validator.deserialize(payload, {}, None)
-        assert (
-            e.value.args[0] == "Protobuf message class not found for 'trip_created' v9. Must be named 'TripCreatedV9'"
-        )
+        assert e.value.args[0] == "Protobuf message class not found for 'trip_created/9'"
 
     def test_deserialize_fails_on_invalid_payload(self):
         with pytest.raises(ValidationError):
@@ -305,12 +340,22 @@ class TestProtobufValidator:
     def test_serialize_no_error_invalid_data(self):
         message = ProtobufMessageFactory(
             msg_type='device.created',
-            data=protobuf_bad1_pb2.DeviceCreated(foobar=1),
+            data=protobuf_bad_pb2.DeviceCreated(foobar=1),
             protobuf_schema_module=protobuf_pb2,
         )
         # invalid data is ignored so long as its a valid protobuf class
         self._validator().serialize(message)
 
+    def test_serialize_raises_error_invalid_message_type(self):
+        message = ProtobufMessageFactory(
+            msg_type='invalid',
+            data=protobuf_pb2.DeviceCreatedV1(device_id="abcd", user_id="U_123"),
+            protobuf_schema_module=protobuf_pb2,
+        )
+        with pytest.raises(ValidationError) as e:
+            self._validator().serialize(message)
+        assert e.value.args[0] == "Protobuf message class not found for 'invalid/1'"
+
     def test_serialize_raises_error_invalid_minor_version(self):
         message = ProtobufMessageFactory(
             msg_type='device.created',
